# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - MoinShare library

    @copyright: 2011, 2012, 2013 by Paul Boddie <paul@boddie.org.uk>
    @license: GNU GPL (v2 or later), see COPYING.txt for details.
"""

from ContentTypeSupport import getContentPreferences
from DateSupport import getCurrentTime
from MoinSupport import *
from MoinMoin import wikiutil
import re

escape = wikiutil.escape
_getFragments = getFragments

__version__ = "0.1"

# More Moin 1.9 compatibility functions.

def has_member(request, groupname, username):
    if hasattr(request.dicts, "has_member"):
        return request.dicts.has_member(groupname, username)
    else:
        return username in request.dicts.get(groupname, [])

# Fragments employ a "moinshare" attribute.

fragment_attribute = "moinshare"

def getFragments(s):
    fragments = []
    for format, attributes, body in _getFragments(s):
        if attributes.has_key(fragment_attribute):
            fragments.append((format, attributes, body))
    return fragments

def getOutputTypes(request, format):

    """
    Using the 'request' and the 'format' of a fragment, return the media types
    available for the fragment.
    """

    # This uses an extended parser API method if available.

    parser = getParserClass(request, format)
    if hasattr(parser, "getOutputTypes"):
        return parser.getOutputTypes()
    else:
        return ["text/html"]

def getPreferredOutputTypes(request, mimetypes):

    """
    Using the 'request', perform content negotiation, obtaining mimetypes common
    to the fragment (given by 'mimetypes') and the client (found in the Accept
    header).
    """

    accept = getHeader(request, "Accept", "HTTP")
    if accept:
        prefs = getContentPreferences(accept)
        return prefs.get_preferred_types(mimetypes)
    else:
        return mimetypes

def getUpdatedTime(metadata):

    """
    Return the last updated time based on the given 'metadata', using the
    current time if no explicit last modified time is specified.
    """

    # NOTE: We could attempt to get the last edit time of a fragment.

    latest_timestamp = metadata.get("last-modified")
    if latest_timestamp:
        return latest_timestamp.as_ISO8601_datetime_string()
    else:
        return getCurrentTime().as_ISO8601_datetime_string()

# vim: tabstop=4 expandtab shiftwidth=4
